==> oarepo_model_builder_drafts-4.0.18-py3-none-any.whl: oarepo_model_builder_drafts/invenio/__init__.py <==
TEMPLATES = {
    "drafts-record-extra-fields": "templates/invenio_drafts_record_extra_fields.py.jinja2",  # adds drafts extension fields to record
    "drafts-record-metadata-extra-fields": "templates/invenio_drafts_record_metadata_extra_fields.py.jinja2",  # adds parent specific fields to model metadata classes
    "drafts-parent-record": "templates/invenio_drafts_parent_record.py.jinja2",  # adds draft parent record class
    "drafts-parent-extra-fields": "templates/invenio_drafts_parent_extra_fields.py.jinja2",
    "drafts-parent-metadata": "templates/invenio_drafts_parent_metadata.py.jinja2",  # adds draft parent metadata classes
    "drafts-record-service-config": "templates/invenio_drafts_record_service_config.py.jinja2",
    "drafts-parent-marshmallow": "templates/invenio_drafts_parent_marshmallow.py.jinja2",
    "drafts-parent-marshmallow-link": "templates/invenio_drafts_parent_marshmallow_link.py.jinja2",
    "drafts-published-record-service-config": "templates/invenio_drafts_published_record_service_config.py.jinja2",
    "drafts-published-record-service": "templates/invenio_drafts_published_record_service.py.jinja2",
    "drafts-parent-state": "templates/invenio_drafts_parent_state.py.jinja2",
    "drafts-has-draft-checkfield": "templates/invenio_drafts_has_draft_checkfield.py.jinja2",
    "drafts-published-ext-service": "templates/invenio_drafts_published_ext_service.py.jinja2",
    "drafts-api-views-published": "templates/invenio_drafts_api_views_published.py.jinja2",
    "drafts-app-views-published": "templates/invenio_drafts_app_views_published.py.jinja2",
    "drafts-proxies": "templates/invenio_drafts_proxies.py.jinja2",
    "drafts-record-communities-service-config": "templates/invenio_drafts_record_communities_service_config.py.jinja2",
}

==> oarepo_model_builder_drafts-4.0.21-py3-none-any.whl: oarepo_model_builder_drafts/invenio/__init__.py <==
TEMPLATES = {
    "drafts-record-extra-fields": "templates/invenio_drafts_record_extra_fields.py.jinja2",  # adds drafts extension fields to record
    "drafts-record-metadata-extra-fields": "templates/invenio_drafts_record_metadata_extra_fields.py.jinja2",  # adds parent specific fields to model metadata classes
    "drafts-parent-record": "templates/invenio_drafts_parent_record.py.jinja2",  # adds draft parent record class
    "drafts-parent-additional-fields": "templates/invenio_drafts_parent_additional_fields.py.jinja2",
    "drafts-parent-metadata": "templates/invenio_drafts_parent_metadata.py.jinja2",  # adds draft parent metadata classes
    "drafts-record-service-config": "templates/invenio_drafts_record_service_config.py.jinja2",
    "drafts-parent-marshmallow": "templates/invenio_drafts_parent_marshmallow.py.jinja2",
    "drafts-parent-marshmallow-link": "templates/invenio_drafts_parent_marshmallow_link.py.jinja2",
    "drafts-published-record-service-config": "templates/invenio_drafts_published_record_service_config.py.jinja2",
    "drafts-published-record-service": "templates/invenio_drafts_published_record_service.py.jinja2",
    "drafts-parent-state": "templates/invenio_drafts_parent_state.py.jinja2",
    "drafts-has-draft-checkfield": "templates/invenio_drafts_has_draft_checkfield.py.jinja2",
    "drafts-published-ext-service": "templates/invenio_drafts_published_ext_service.py.jinja2",
    "drafts-api-views-published": "templates/invenio_drafts_api_views_published.py.jinja2",
    "drafts-app-views-published": "templates/invenio_drafts_app_views_published.py.jinja2",
    "drafts-proxies": "templates/invenio_drafts_proxies.py.jinja2",
    "drafts-record-communities-service-config": "templates/invenio_drafts_record_communities_service_config.py.jinja2",
}
